#[non_exhaustive]pub enum Error {
Show 24 variants
Io(Error),
Bcs(Error),
Chain(ChainError),
ChainClient(Error),
Options(Error),
Wallet(Box<dyn Error + Send + Sync>),
View(ViewError),
LocalNode(LocalNodeError),
RemoteNode(NodeError),
Arithmetic(ArithmeticError),
ChainOwnership,
Benchmark(BenchmarkError),
AssignChain(Box<dyn Error + Send + Sync>),
ChangeOwnership(Box<Error>),
PublishModule(Box<Error>),
PublishDataBlob(Box<Error>),
VerifyDataBlob(Box<Error>),
DeliverNewChainMessages(Box<Error>),
UnexpectedVersionInfo {
remote: Box<VersionInfo>,
local: Box<VersionInfo>,
},
UnavailableVersionInfo {
address: String,
error: Box<NodeError>,
},
UnexpectedNetworkDescription {
remote: Box<NetworkDescription>,
local: Box<NetworkDescription>,
},
UnavailableNetworkDescription {
address: String,
error: Box<NodeError>,
},
InvalidSignature {
public_key: ValidatorPublicKey,
},
UnavailableChainInfo {
address: String,
chain_id: ChainId,
error: Box<NodeError>,
},
}Expand description
The kinds of error that the client can return.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Io(Error)
An I/O operation failed.
Bcs(Error)
A value could not be BCS-serialized or -deserialized.
Chain(ChainError)
An operation on a chain failed.
ChainClient(Error)
An operation performed through the chain client failed.
Options(Error)
The client options were invalid.
Wallet(Box<dyn Error + Send + Sync>)
An operation on the wallet backend failed.
View(ViewError)
An operation on a view failed.
LocalNode(LocalNodeError)
An operation on the local node failed.
RemoteNode(NodeError)
An operation on a remote validator failed.
Arithmetic(ArithmeticError)
An arithmetic operation overflowed.
ChainOwnership
The chain is not owned by the expected owner.
Benchmark(BenchmarkError)
A benchmark run failed.
AssignChain(Box<dyn Error + Send + Sync>)
The new chain could not be assigned to the wallet.
ChangeOwnership(Box<Error>)
The chain’s ownership could not be changed.
PublishModule(Box<Error>)
The module could not be published.
PublishDataBlob(Box<Error>)
The data blob could not be published.
VerifyDataBlob(Box<Error>)
The data blob could not be read back after publishing.
DeliverNewChainMessages(Box<Error>)
The messages that create the new chains could not be delivered.
UnexpectedVersionInfo
A validator is running an incompatible version.
A validator’s version could not be retrieved.
UnexpectedNetworkDescription
A validator disagrees with us about the network.
Fields
remote: Box<NetworkDescription>The validator’s network description.
local: Box<NetworkDescription>Our own network description.
A validator’s network description could not be retrieved.
InvalidSignature
A validator’s signature did not verify.
Fields
public_key: ValidatorPublicKeyThe public key the signature was checked against.
A validator’s information about a chain could not be retrieved.
Implementations